@@ -17,7 +17,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(setup_file);
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 our %SPEC;
 
@@ -527,7 +527,7 @@ Setup::File - Setup file (existence, mode, permission, content)
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -552,101 +552,13 @@ version 0.13
 
 =head1 DESCRIPTION
 
-This module provides one function: B<setup_file>.
-
-This module is part of the Setup modules family.
-
 This module uses L<Log::Any> logging framework.
 
-This module's functions have L<Rinci> metadata.
-
-=head1 THE SETUP MODULES FAMILY
-
-I use the C<Setup::> namespace for the Setup modules family. These family of
-modules are typically used in installers. They must support uninstallation
-(reverse/undo) and be flexible enough to deal with external state changes.
-
-To "setup" something means to set something into a desired state. For example,
-L<Setup::File> sets up a file with a specified permission mode, ownership, and
-content. If the file doesn't exist it will be created; if a directory exists
-instead, it will be removed and replaced with the file; if the file already
-exists but with incorrect permission/owner/content, it will be corrected.
-Another example is L<Setup::Unix::User>, which will setup a Unix user (with the
-correct specified group membership). If everything is already correct, nothing
-is done (the function returns 304 status). In other words, setup function should
-be idempotent. One should be able to run it multiple times safely to reach the
-desired state.
-
-A simulation (dry run) mode also exists: if you pass L<-dry_run> => 1 argument
-to the function, it will check states and report inconsistencies, but will
-modify nothing and return 200 status (or 304) immediately instead. See the
-"dry_run" feature in L<Rinci::function> for more details on dry running.
-
-After the setup, the function returns undo data, which can be used to perform
-undo ("unsetup", "uninstallation") later. The undo data is serializable and thus
-can be stored in persistent storage. When doing undo, the undo data is fed into
-the C<-undo_data> argument, along with other same arguments specified during the
-previous "do" phase. See the "undo" feature in L<Rinci::function> for more
-details on the undo protocol. Undo will reverse all actions done by the function
-in the "do" phase; for example, if a file was created by the function it will be
-deleted (if it hasn't changed since the creation), if an existing file's
-mode/ownership was changed, it will be restored, and so on.
-
-There could be various state changes between the time of do and undo; a file can
-be deleted or modified by other processes. The undo must be flexible enough so
-it can reverse whatever state changes the previous do phase did whenever it can,
-but not disrupt other processes' changes.
-
-After an undo, the function returns undo_data, which can be used to perform undo
-of undo (redo) later.
-
-=head2 Implementation
-
-Below is the general view on implementation of a setup module. For more details,
-delve directly into the source code.
-
-We divide setup into a series of unit steps. For example, setting up a file is
-comprised of steps: create, chown, chmod. Or it can just be: set_content, chown,
-chmod, if the file already exists. Or: rm, create, chown, chmod, if a directory
-exists and must be removed first.
-
-To perform setup, we begin with an empty list of steps and add necessary steps
-according to the current state. To perform undo, we are given undo data, which
-is just the list of steps generated by previous invocation.
-
-After we have the list of steps, we perform them one by one sequentially. Each
-step comes with its own state checking and can be skipped if the desired state
-is already reached. After performing a step, we also add an undo step to the
-undo steps list. If an error is encountered in a step, we can perform a
-rollback, which basically means we perform the undo steps formed up to that
-point. (If error is encountered during rollback, we die.)
-
-After all steps have been done successfully, we return 200.
-
-=head2 Undo data
-
-Undo data should be a list of steps:
-
- [undo_step1, undo_step2, ...]
-
-Undo step is usually a command followed by a list of args, examples:
-
- ["reset"]
- ["rm", "file1"]
- ["do", "Setup::File::setup_file", {arg1=>..., arg2=>...}]
- ["undo", "Setup::File::setup_file", $args, $undo_data]
-
-Because undo data might be needed much later after it is generated (e.g. months
-or even years later when a software is finally uninstalled), please plan a
-stable list of commands and its arguments carefully, so much newer version of
-your setup module can still perform undo using undo data produced by older
-version of your setup module. Existing commands should still be supported as
-long as possible, unless absolutely necessary that it is abandoned. Changes in
-the order of command arguments should also be kept minimal.
+This module has L<Rinci> metadata.
 
 =head1 SEE ALSO
 
-Other modules in Setup:: namespace.
+L<Setup>
 
 =head1 FUNCTIONS
 
