@@ -11,7 +11,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(setup_dir);
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 our %SPEC;
 
@@ -108,7 +108,7 @@ Setup::File::Dir - Setup directory (existence, mode, permission)
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -134,25 +134,15 @@ version 0.13
 
 =head1 DESCRIPTION
 
-This module provides one function: B<setup_dir>.
-
-This module is part of the Setup modules family.
-
 This module uses L<Log::Any> logging framework.
 
-This module's functions have L<Rinci> metadata.
-
-=head1 THE SETUP MODULES FAMILY
-
-I use the C<Setup::> namespace for the Setup modules family. See L<Setup::File>
-for more details on the goals, characteristics, and implementation of Setup
-modules family.
+This module has L<Rinci> metadata.
 
 =head1 SEE ALSO
 
-L<Setup::File>.
+L<Setup::File>
 
-Other modules in Setup:: namespace.
+L<Setup>
 
 =head1 FUNCTIONS
 
